@@ -50,10 +50,12 @@
 #'   [`bayestestR::equivalence_test()`] resp. [`parameters::equivalence_test.lm()`]
 #'   for details.
 #' @param p_adjust Character vector, if not `NULL`, indicates the method to
-#'   adjust p-values. See [`stats::p.adjust()`] for details. Further possible
-#'   adjustment methods are `"tukey"` or `"sidak"`. Some caution is necessary
-#'   when adjusting p-value for multiple comparisons. See also section
-#'   _P-value adjustment_ below.
+#'   adjust p-values. See [`stats::p.adjust()`] or [`stats::p.adjust.methods`]
+#'   for details. Further possible adjustment methods are `"tukey"` or `"sidak"`,
+#'   and for `johnson_neyman()`, `"fdr"` (or `"bh"`) and `"esarey"` (or its
+#'   short-cut `"es"`) are available options. Some caution is necessary when
+#'   adjusting p-value for multiple comparisons. See also section _P-value adjustment_
+#'   below.
 #' @param df Degrees of freedom that will be used to compute the p-values and
 #'   confidence intervals. If `NULL`, degrees of freedom will be extracted from
 #'   the model using [`insight::get_df()`] with `type = "wald"`.
@@ -70,7 +72,12 @@
 #'   calculate heteroscedasticity-consistent standard errors for contrasts.
 #'   See examples at the bottom of
 #'   [this vignette](https://strengejacke.github.io/ggeffects/articles/introduction_comparisons_1.html)
-#'   for further details.
+#'   for further details. Note the different ways to define the heteroscedasticity-consistent
+#'   variance-covariance matrix for `ggpredict()` and `hypothesis_test()` resp.
+#'   `johnson_neyman()`. For `ggpredict()`, the arguments are named `vcov_fun`
+#'   and `vcov_args`, whereas for `hypothesis_test()` and `johnson_neyman()`,
+#'   there is only the argument `vcov`. See `?marginaleffects::slopes` for
+#'   further details.
 #'
 #' @seealso There is also an `equivalence_test()` method in the **parameters**
 #'   package ([`parameters::equivalence_test.lm()`]), which can be used to
@@ -102,10 +109,22 @@
 #' in `terms`. Thus, the latter two methods may be useful for certain tests
 #' only, in particular pairwise comparisons.
 #'
+#' For `johnson_neyman()`, the only available adjustment methods are `"fdr"`
+#' (or `"bh"`) (_Benjamini & Hochberg (1995)_) and `"esarey"` (or `"es"`)
+#' (_Esarey and Sumner 2017_). These usually return similar results. The major
+#' difference is that `"fdr"` can be slightly faster and more stable in edge
+#' cases, however, confidence intervals are not updated. Only the p-values are
+#' adjusted. `"esarey"` is slower, but confidence intervals are updated as well.
+#'
 #' @return A data frame containing predictions (e.g. for `test = NULL`),
 #' contrasts or pairwise comparisons of adjusted predictions or estimated
 #' marginal means.
 #'
+#' @references
+#' Esarey, J., & Sumner, J. L. (2017). Marginal effects in interaction models:
+#' Determining and controlling the false positive rate. Comparative Political
+#' Studies, 1–33. Advance online publication. doi: 10.1177/0010414017730080
+#'
 #' @examplesIf requireNamespace("marginaleffects") && requireNamespace("parameters") && interactive()
 #' \donttest{
 #' data(efc)
@@ -181,7 +200,7 @@ hypothesis_test.default <- function(model,
                                     ci.lvl = ci_level,
                                     ...) {
   # check if we have the appropriate package version installed
-  insight::check_if_installed("marginaleffects", minimum_version = "0.10.0")
+  insight::check_if_installed("marginaleffects", minimum_version = "0.16.0")
 
   # when model is a "ggeffects" object, due to environment issues, "model"
   # can be NULL (in particular in tests), thus check for NULL
@@ -196,6 +215,11 @@ hypothesis_test.default <- function(model,
     )
   }
 
+  # for parsnip-models, use $fit element
+  if (inherits(model, "model_fit")) {
+    model <- model$fit
+  }
+
   # process arguments
   if (!missing(ci.lvl)) {
     insight::format_warning("Argument `ci.lvl` is deprecated. Please use `ci_level` instead.")
@@ -315,8 +339,8 @@ hypothesis_test.default <- function(model,
   invalid_names <- reserved %in% colnames(grid)
   if (any(invalid_names)) {
     insight::format_error(
-      "Some variable names in the model are not allowed when using `hyothesis_test()` because they are reserved by the internally used {.pkg marginaleffects} package.",
-      paste0("Please rename following variables and fit your model again: ", toString(paste0("`", reserved[invalid_names], "`")))
+      "Some variable names in the model are not allowed when using `hyothesis_test()` because they are reserved by the internally used {.pkg marginaleffects} package.", # nolint
+      paste0("Please rename following variables and fit your model again: ", toString(paste0("`", reserved[invalid_names], "`"))) # nolint
     )
   }
 
@@ -565,7 +589,7 @@ hypothesis_test.default <- function(model,
         # factor levels. When we have row numbers, we coerce them to numeric and
         # extract related factor levels. Else, in case of ordinal outcomes, we
         # should already have factor levels...
-        if (all(vapply(contrast_terms, function(i) anyNA(as.numeric(i)), TRUE)) || minfo$is_ordinal || minfo$is_multinomial) {
+        if (all(vapply(contrast_terms, function(i) anyNA(as.numeric(i)), TRUE)) || minfo$is_ordinal || minfo$is_multinomial) { # nolint
           out <- as.data.frame(lapply(focal, function(i) {
             unlist(lapply(seq_len(nrow(contrast_terms)), function(j) {
               .contrasts_string <- paste(unlist(contrast_terms[j, ]), collapse = "-")
@@ -701,7 +725,7 @@ hypothesis_test.default <- function(model,
 
   # p-value adjustment?
   if (!is.null(p_adjust)) {
-    out <- .p_adjust(out, p_adjust, .comparisons$statistic, grid, focal, df, verbose)
+    out <- .p_adjust(out, p_adjust, grid, focal, .comparisons$statistic, df, verbose)
   }
 
   # add back response levels?
@@ -734,6 +758,9 @@ hypothesis_test.default <- function(model,
   attr(out, "msg_intervals") <- msg_intervals
   attr(out, "verbose") <- verbose
   attr(out, "standard_error") <- .comparisons$std.error
+  attr(out, "link_inverse") <- insight::link_inverse(model)
+  attr(out, "link_function") <- insight::link_function(model)
+
   out
 }
 
@@ -744,6 +771,7 @@ hypothesis_test.ggeffects <- function(model,
                                       by = NULL,
                                       test = "pairwise",
                                       equivalence = NULL,
+                                      scale = "response",
                                       p_adjust = NULL,
                                       df = NULL,
                                       collapse_levels = FALSE,
@@ -762,6 +790,7 @@ hypothesis_test.ggeffects <- function(model,
     by = by,
     test = test,
     equivalence = equivalence,
+    scale = scale,
     p_adjust = p_adjust,
     df = df,
     ci_level = ci_level,
@@ -776,7 +805,7 @@ hypothesis_test.ggeffects <- function(model,
 
 
 .collapse_levels <- function(out, grid, focal, by) {
-  # remove by-terms from focal terms  
+  # remove by-terms from focal terms
   if (!is.null(by)) {
     focal <- focal[!focal %in% by]
   }
@@ -1016,7 +1045,7 @@ plot.see_equivalence_test_ggeffects <- function(x,
 
   fill.color <- fill.color[sort(unique(match(x$ROPE_Equivalence, c("Accepted", "Rejected", "Undecided"))))]
 
-  add.args <- lapply(match.call(expand.dots = FALSE)$`...`, function(x) x)
+  add.args <- match.call(expand.dots = FALSE)[["..."]]
   if ("colors" %in% names(add.args)) fill.color <- eval(add.args[["colors"]])
   if ("x.title" %in% names(add.args)) x.title <- eval(add.args[["x.title"]])
   if ("legend.title" %in% names(add.args)) legend.title <- eval(add.args[["legend.title"]])
@@ -1080,7 +1109,12 @@ plot.see_equivalence_test_ggeffects <- function(x,
 
 # p-value adjustment -------------------
 
-.p_adjust <- function(params, p_adjust, statistic = NULL, grid, focal, df = Inf, verbose = TRUE) {
+.p_adjust <- function(params, p_adjust, grid, focal, statistic = NULL, df = Inf, verbose = TRUE) {
+  # exit on NULL, or if no p-adjustment requested
+  if (is.null(p_adjust) || identical(p_adjust, "none")) {
+    return(params)
+  }
+
   all_methods <- c(tolower(stats::p.adjust.methods), "tukey", "sidak")
 
   # needed for rank adjustment
