@@ -6,6 +6,8 @@
 #' @param object An object of class `"ggeffects"`, as returned by `ggpredict()`.
 #' @param ... Currently not used.
 #' @inheritParams ggpredict
+#' @param vcov.fun,vcov.type,vcov.args Deprecated. Use `vcov_fun`, `vcov_type`
+#' and `vcov_args` instead.
 #'
 #' @return The variance-covariance matrix for the predicted values from `object`.
 #'
@@ -38,7 +40,14 @@
 #' result <- ggpredict(model, c("c161sex", "c172code"))
 #' vcov(result)
 #' @export
-vcov.ggeffects <- function(object, vcov.fun = NULL, vcov.type = NULL, vcov.args = NULL, ...) {
+vcov.ggeffects <- function(object,
+                           vcov_fun = NULL,
+                           vcov_type = NULL,
+                           vcov_args = NULL,
+                           vcov.fun = vcov_fun,
+                           vcov.type = vcov_type,
+                           vcov.args = vcov_args,
+                           ...) {
   model <- .safe(get(attr(object, "model.name"), envir = parent.frame()))
 
   if (is.null(model)) {
@@ -68,23 +77,19 @@ vcov.ggeffects <- function(object, vcov.fun = NULL, vcov.type = NULL, vcov.args
   condition <- attr(object, "condition")
   if (!is.null(condition)) {
     cn <- names(condition)
-    cn.factors <- sapply(cn, function(.x) is.factor(model_frame[[.x]]) && !(.x %in% random_effect_terms))
+    cn.factors <- vapply(
+      cn,
+      function(.x) is.factor(model_frame[[.x]]) && !(.x %in% random_effect_terms),
+      logical(1)
+    )
     condition <- condition[!cn.factors]
     if (.is_empty(condition)) condition <- NULL
   }
 
   const.values <- attr(object, "constant.values")
-  const.values <- c(condition, unlist(const.values[sapply(const.values, is.numeric)]))
+  const.values <- c(condition, unlist(const.values[vapply(const.values, is.numeric, logical(1))]))
   terms <- attr(object, "original.terms")
 
-
-  ## TODO fpr debugging
-  add.args <- lapply(match.call(expand.dots = FALSE)$`...`, function(x) x)
-  if (isTRUE(add.args[["debug"]])) {
-    message("Collection 1")
-    print(gc(TRUE))
-  }
-
   # copy data frame with predictions
   newdata <- .data_grid(
     model,
@@ -93,20 +98,12 @@ vcov.ggeffects <- function(object, vcov.fun = NULL, vcov.type = NULL, vcov.args
     value_adjustment = "mean",
     factor_adjustment = FALSE,
     show_pretty_message = FALSE,
-    condition = const.values
+    condition = const.values,
+    verbose = FALSE
   )
 
-
-  ## TODO fpr debugging
-  if (isTRUE(add.args[["debug"]])) {
-    message("Collection 2")
-    print(gc(TRUE))
-  }
-
-
   # add response to newdata. For models fitted with "glmmPQL",
   # the response variable is renamed internally to "zz".
-
   if (inherits(model, "glmmPQL")) {
     new_response <- 0
     names(new_response) <- "zz"
@@ -140,12 +137,11 @@ vcov.ggeffects <- function(object, vcov.fun = NULL, vcov.type = NULL, vcov.args
   # rownames were resorted as well, which causes troubles in model.matrix
   rownames(newdata) <- NULL
   tryCatch(
-    {
-      .vcov_helper(
-        model, model_frame, get_predict_function(model), newdata,
-        vcov.fun, vcov.type, vcov.args, terms, full.vcov = TRUE
-      )
-    },
+    .vcov_helper(
+      model, model_frame, get_predict_function(model), newdata,
+      vcov.fun = vcov_fun, vcov.type = vcov_type, vcov.args = vcov_args,
+      terms, full.vcov = TRUE
+    ),
     error = function(e) {
       insight::format_alert(
         "Could not compute variance-covariance matrix of predictions. No confidence intervals are returned."
@@ -201,7 +197,7 @@ vcov.ggeffects <- function(object, vcov.fun = NULL, vcov.type = NULL, vcov.args
         insight::format_alert(paste0(
           "Can't compute robust standard errors for models of class `",
           class(model)[1],
-          "` when `vcov.fun=\"vcovCR\". Please use `vcov.fun=\"vcovCL\"` from the {sandwich} package instead."
+          "` when `vcov_fun=\"vcovCR\". Please use `vcov_fun=\"vcovCL\"` from the {sandwich} package instead."
         ))
         return(NULL)
       }
@@ -224,12 +220,10 @@ vcov.ggeffects <- function(object, vcov.fun = NULL, vcov.type = NULL, vcov.args
   }
 
 
-  model_terms <- tryCatch({
-    stats::terms(model)
-  },
-  error = function(e) {
-    insight::find_formula(model)$conditional
-  })
+  model_terms <- tryCatch(
+    stats::terms(model),
+    error = function(e) insight::find_formula(model)$conditional
+  )
 
   # exception for gamlss, who may have "random()" function in formula
   # we need to remove this term...
@@ -260,9 +254,10 @@ vcov.ggeffects <- function(object, vcov.fun = NULL, vcov.type = NULL, vcov.args
 
   re.terms <- insight::find_random(model, split_nested = TRUE, flatten = TRUE)
 
-  nlevels_terms <- sapply(
+  nlevels_terms <- vapply(
     colnames(newdata),
-    function(.x) !(.x %in% re.terms) && is.factor(newdata[[.x]]) && nlevels(newdata[[.x]]) == 1
+    function(.x) !(.x %in% re.terms) && is.factor(newdata[[.x]]) && nlevels(newdata[[.x]]) == 1,
+    logical(1)
   )
 
   if (any(nlevels_terms)) {
@@ -275,7 +270,7 @@ vcov.ggeffects <- function(object, vcov.fun = NULL, vcov.type = NULL, vcov.args
   }
 
   # code to compute se of prediction taken from
-  # http://bbolker.github.io/mixedmodels-misc/glmmFAQ.html#predictions-andor-confidence-or-prediction-intervals-on-predictions
+  # http://bbolker.github.io/mixedmodels-misc/glmmFAQ.html#predictions-andor-confidence-or-prediction-intervals-on-predictions # nolint
   mm <- stats::model.matrix(model_terms, newdata)
 
   # here we need to fix some term names, so variable names match the column
